@@ -10,20 +10,20 @@
  * version 2 of the License, or (at your option) any later version.
  *
  * \par
- * This library is distributed in the hope that it will be useful, 
- * but WITHOUT ANY WARRANTY; without even the implied warranty of 
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details. 
+ * Lesser General Public License for more details.
  *
  * \par
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  */
 
-#ifndef __GPHOTO2_ABILITIES_LIST_H__
-#define __GPHOTO2_ABILITIES_LIST_H__
+#ifndef LIBGPHOTO2_GPHOTO2_ABILITIES_LIST_H
+#define LIBGPHOTO2_GPHOTO2_ABILITIES_LIST_H
 
 #include <gphoto2/gphoto2-context.h>
 #include <gphoto2/gphoto2-list.h>
@@ -50,8 +50,8 @@ typedef enum {
  * and MTP Audio Players.
  */
 typedef enum {
-        GP_DEVICE_STILL_CAMERA          = 0,	 /**< Traditional still camera */
-        GP_DEVICE_AUDIO_PLAYER          = 1 << 0 /**< Audio player */
+	GP_DEVICE_STILL_CAMERA          = 0,	 /**< Traditional still camera */
+	GP_DEVICE_AUDIO_PLAYER          = 1 << 0 /**< Audio player */
 } GphotoDeviceType;
 
 /**
@@ -59,35 +59,36 @@ typedef enum {
  * Some drivers might support additional dynamic capabilities (like the PTP driver).
  */
 typedef enum {
-        GP_OPERATION_NONE       	= 0,	  /**< No remote control operation supported. */
-        GP_OPERATION_CAPTURE_IMAGE      = 1 << 0, /**< Capturing images supported. */
-        GP_OPERATION_CAPTURE_VIDEO      = 1 << 1, /**< Capturing videos supported. */
-        GP_OPERATION_CAPTURE_AUDIO      = 1 << 2, /**< Capturing audio supported. */
-        GP_OPERATION_CAPTURE_PREVIEW    = 1 << 3, /**< Capturing image previews supported. */
-        GP_OPERATION_CONFIG             = 1 << 4  /**< Camera and Driver configuration supported. */
+	GP_OPERATION_NONE               = 0,      /**< No remote control operation supported. */
+	GP_OPERATION_CAPTURE_IMAGE      = 1 << 0, /**< Capturing images supported. */
+	GP_OPERATION_CAPTURE_VIDEO      = 1 << 1, /**< Capturing videos supported. */
+	GP_OPERATION_CAPTURE_AUDIO      = 1 << 2, /**< Capturing audio supported. */
+	GP_OPERATION_CAPTURE_PREVIEW    = 1 << 3, /**< Capturing image previews supported. */
+	GP_OPERATION_CONFIG             = 1 << 4, /**< Camera and Driver configuration supported. */
+	GP_OPERATION_TRIGGER_CAPTURE    = 1 << 5  /**< Camera can trigger capture and wait for events. */
 } CameraOperation;
 
 /**
  * A bitmask of image related operations of the device.
  */
 typedef enum {
-        GP_FILE_OPERATION_NONE          = 0,      /**< No special file operations, just download. */
-        GP_FILE_OPERATION_DELETE        = 1 << 1, /**< Deletion of files is possible. */
-        GP_FILE_OPERATION_PREVIEW       = 1 << 3, /**< Previewing viewfinder content is possible. */
-        GP_FILE_OPERATION_RAW           = 1 << 4, /**< Raw retrieval is possible (used by non-JPEG cameras) */
-        GP_FILE_OPERATION_AUDIO         = 1 << 5, /**< Audio retrieval is possible. */
-        GP_FILE_OPERATION_EXIF          = 1 << 6  /**< EXIF retrieval is possible. */
+	GP_FILE_OPERATION_NONE          = 0,      /**< No special file operations, just download. */
+	GP_FILE_OPERATION_DELETE        = 1 << 1, /**< Deletion of files is possible. */
+	GP_FILE_OPERATION_PREVIEW       = 1 << 3, /**< Previewing viewfinder content is possible. */
+	GP_FILE_OPERATION_RAW           = 1 << 4, /**< Raw retrieval is possible (used by non-JPEG cameras) */
+	GP_FILE_OPERATION_AUDIO         = 1 << 5, /**< Audio retrieval is possible. */
+	GP_FILE_OPERATION_EXIF          = 1 << 6  /**< EXIF retrieval is possible. */
 } CameraFileOperation;
 
 /**
  * A bitmask of filesystem related operations of the device.
  */
 typedef enum {
-        GP_FOLDER_OPERATION_NONE        = 0,	  /**< No special filesystem operation. */
-        GP_FOLDER_OPERATION_DELETE_ALL  = 1 << 0, /**< Deletion of all files on the device. */
-        GP_FOLDER_OPERATION_PUT_FILE    = 1 << 1, /**< Upload of files to the device possible. */
-        GP_FOLDER_OPERATION_MAKE_DIR    = 1 << 2, /**< Making directories on the device possible. */
-        GP_FOLDER_OPERATION_REMOVE_DIR  = 1 << 3  /**< Removing directories from the device possible. */
+	GP_FOLDER_OPERATION_NONE        = 0,      /**< No special filesystem operation. */
+	GP_FOLDER_OPERATION_DELETE_ALL  = 1 << 0, /**< Deletion of all files on the device. */
+	GP_FOLDER_OPERATION_PUT_FILE    = 1 << 1, /**< Upload of files to the device possible. */
+	GP_FOLDER_OPERATION_MAKE_DIR    = 1 << 2, /**< Making directories on the device possible. */
+	GP_FOLDER_OPERATION_REMOVE_DIR  = 1 << 3  /**< Removing directories from the device possible. */
 } CameraFolderOperation;
 
 #ifdef _GPHOTO2_INTERNAL_CODE
@@ -110,46 +111,46 @@ typedef enum {
 #endif /* _GPHOTO2_INTERNAL_CODE */
 
 
-/** 
+/**
  * \brief Describes the properties of a specific camera.
  *
  * The internals of this structures are used extensively by the
  * camlibs, but the status regarding use by frontends is questionable.
  */
 typedef struct {
-        char model [128];			/**< \brief name of camera model */
-        CameraDriverStatus status;		/**< \brief driver quality */
+	char model [128];			/**< \brief name of camera model */
+	CameraDriverStatus status;		/**< \brief driver quality */
 
 	/** \brief Supported port types. */
 	GPPortType port;
 	/** \brief Supported serial port speeds (terminated with a value of 0). */
-        int speed [64];
+	int speed [64];
 
-        /* Supported operations */
-        CameraOperation       operations;	/**< \brief Camera operation funcs */
-        CameraFileOperation   file_operations;  /**< \brief Camera file op funcs */
-        CameraFolderOperation folder_operations;/**< \brief Camera folder op funcs */
+	/* Supported operations */
+	CameraOperation       operations;	/**< \brief Camera operation funcs */
+	CameraFileOperation   file_operations;  /**< \brief Camera file op funcs */
+	CameraFolderOperation folder_operations;/**< \brief Camera folder op funcs */
 
 	int usb_vendor;		/**< \brief USB Vendor D */
 	int usb_product;	/**< \brief USB Product ID */
-	int usb_class;          /**< \brief USB device class */
+	int usb_class;		/**< \brief USB device class */
 	int usb_subclass;	/**< \brief USB device subclass */
 	int usb_protocol;	/**< \brief USB device protocol */
 
-        /* For core use */
-        char library [1024];	/**< \brief (Internal) library filename */
-        char id [1024];		/**< \brief (Internal) camera ID name */
+	/* For core use */
+	char library [1024];	/**< \brief (Internal) library filename */
+	char id [1024];		/**< \brief (Internal) camera ID name */
 
 	GphotoDeviceType 	device_type;	/**< \brief Device type. */
-	/** Reserved space to use in the future w/out changing the 
+	/** Reserved space to use in the future w/out changing the
 	 * struct size */
-        int reserved2;		/**< reserved space \internal */
-        int reserved3;		/**< reserved space \internal */
-        int reserved4;		/**< reserved space \internal */
-        int reserved5;		/**< reserved space \internal */
-        int reserved6;		/**< reserved space \internal */
-        int reserved7;		/**< reserved space \internal */
-        int reserved8;		/**< reserved space \internal */
+	int reserved2;		/**< reserved space \internal */
+	int reserved3;		/**< reserved space \internal */
+	int reserved4;		/**< reserved space \internal */
+	int reserved5;		/**< reserved space \internal */
+	int reserved6;		/**< reserved space \internal */
+	int reserved7;		/**< reserved space \internal */
+	int reserved8;		/**< reserved space \internal */
 } CameraAbilities;
 
 
@@ -165,6 +166,7 @@ int gp_abilities_list_new    (CameraAbilitiesList **list);
 int gp_abilities_list_free   (CameraAbilitiesList *list);
 
 int gp_abilities_list_load   (CameraAbilitiesList *list, GPContext *context);
+int gp_abilities_list_load_dir   (CameraAbilitiesList *list, const char *dir, GPContext *context);
 int gp_abilities_list_reset  (CameraAbilitiesList *list);
 
 int gp_abilities_list_detect (CameraAbilitiesList *list,
@@ -184,6 +186,8 @@ int gp_abilities_list_get_abilities (CameraAbilitiesList *list, int index,
 
 const char *gp_message_codeset (const char *);
 
+int gp_init_localedir (const char *localedir);
+
 
 /**
  * Name of the environment variable which may contain the path where
@@ -194,6 +198,7 @@ const char *gp_message_codeset (const char *);
  */
 #ifdef _GPHOTO2_INTERNAL_CODE
 #define CAMLIBDIR_ENV "CAMLIBS"
+#define CAMLIBDIR_PREFIX_ENV "CAMLIBS_PREFIX"
 #endif /* _GPHOTO2_INTERNAL_CODE */
 
 
@@ -201,4 +206,4 @@ const char *gp_message_codeset (const char *);
 }
 #endif /* __cplusplus */
 
-#endif /* __GPHOTO2_ABILITIES_LIST_H__ */
+#endif /* !defined(LIBGPHOTO2_GPHOTO2_ABILITIES_LIST_H) */
